@@ -12,13 +12,13 @@
 #include <QDebug>
 #include <QDialogButtonBox>
 
-#include <Plasma/DataEngine>
-#include <Plasma/Service>
-#include <Plasma/ServiceJob>
+#include <Plasma5Support/DataEngine>
+#include <Plasma5Support/Service>
+#include <Plasma5Support/ServiceJob>
 
 #include "engineexplorer.h"
 
-ServiceViewer::ServiceViewer(Plasma::DataEngine *engine, const QString &source, QWidget *parent)
+ServiceViewer::ServiceViewer(Plasma5Support::DataEngine *engine, const QString &source, QWidget *parent)
     : QDialog(parent)
     , m_engine(engine)
     , m_service(nullptr)
@@ -46,7 +46,9 @@ ServiceViewer::ServiceViewer(Plasma::DataEngine *engine, const QString &source,
     connect(m_operationButton, &QAbstractButton::clicked, this, &ServiceViewer::startOperation);
     m_operationButton->setEnabled(false);
 
-    connect(m_operations, SIGNAL(currentIndexChanged(QString)), this, SLOT(operationSelected(QString)));
+    connect(m_operations, &KComboBox::currentIndexChanged, this, [this](int index) {
+        operationSelected(m_operations->itemText(index));
+    });
 
     QString engineName = i18nc("Plasma engine with unknown name", "Unknown");
     QString serviceName = i18nc("Plasma service with unknown name", "Unknown");
@@ -136,7 +138,7 @@ void ServiceViewer::startOperation()
     }
 
     updateJobCount(1);
-    Plasma::ServiceJob *job = m_service->startOperationCall(desc);
+    Plasma5Support::ServiceJob *job = m_service->startOperationCall(desc);
     connect(job, &KJob::finished, this, &ServiceViewer::operationResult);
 }
 
@@ -173,7 +175,7 @@ void ServiceViewer::operationResult(KJob *j)
         return;
     }
 
-    Plasma::ServiceJob *job = qobject_cast<Plasma::ServiceJob *>(j);
+    Plasma5Support::ServiceJob *job = qobject_cast<Plasma5Support::ServiceJob *>(j);
     if (!job) {
         return;
     }
@@ -227,3 +229,5 @@ void ServiceViewer::updateJobCount(int numberOfJobs)
         m_operationStatus->show();
     }
 }
+
+#include "moc_serviceviewer.cpp"
